videosdk library

Classes

AgentParticipant
Represents an AI agent participant in the room.
AudioDeviceInfo
Represents information about an audio input or output device.
BaseKeyProvider
Default implementation of KeyProviderBase used for end-to-end encryption.
CustomTrack
Represents a custom media track.
MediaDeviceInfo
This describe the media input and output devices, such as microphones, cameras, headsets, and so forth.
NotificationInfo
Holds the information needed to display a notification.
Participant
Represents a participant in the room and provides access to their media, state, and event-related operations.
ParticipantPinState
Represents the pin state of a participant's media streams.
PostTranscriptionConfig
Configuration for post-transcription processing.
PubSub
Represents the PubSub (Publish-Subscribe) mechanism for the room.
PubSubMessage
Represents a single PubSub message.
PubSubMessages
Represents a collection of PubSub messages.
PubSubPublishOptions
Represents the options for publishing a PubSub message.
RealtimeStore
Represents a key-value store for realtime data synchronization in the room.
Room
RTCVideoRenderer
RTCVideoView
Stream
Represents a media stream in a VideoSDK room.
SummaryConfig
Configuration for transcription summary generation.
TranscriptionConfig
Configuration for the transcription service.
TranscriptionSegment
A transcription segment produced by an AI agent.
TranscriptionText
Represents a segment of transcribed text.
VideoDeviceInfo
Represents information about a video input device (camera).
VideoSDK
VideoSDK Class is a core class of SDK that provides methods to create and configure VideoSDK Room.

Enums

AgentState
Represents the operational state of an AI agent participant.
BitrateMode
Defines the video bitrate optimization mode.
CustomAudioTrackConfig
Defines audio quality presets for microphone audio tracks.
CustomScreenShareTrackConfig
Defines resolution and frame-rate presets for screen sharing.
CustomTrackKind
Defines the type of custom track.
CustomVideoTrackConfig
Defines video resolution and encoding presets for camera video tracks.
E2EEState
Defines the end-to-end encryption (E2EE) states for media streams.
Events
Defines all event types emitted by the VideoSDK.
FacingMode
Defines the camera facing mode for video capture.
LeaveReason
Represents the reason why a participant left the meeting.
LogLevel
Defines the available logging levels for the SDK.
Mode
Defines the media participation mode of a participant in the room.
Permissions
Defines the media permissions that can be requested by the application.
PinType
Defines the pinning behavior for a participant's media streams.
RoomState
Defines the connection states of a room.
RTCVideoViewObjectFit
TranscriptionState
Represents the current state of the real-time transcription service.

Properties

VideoSDKErrors Map<int, Map<String, String>>
A centralized map of all VideoSDK error codes.
getter/setter pair