AgentState enum

Represents the operational state of an AI agent participant.

Values

Inheritance
Available extensions

Values

idle → const AgentState

The agent is idle and not processing anything.

listening → const AgentState

The agent is actively listening to audio input.

thinking → const AgentState

The agent is processing input or generating a response.

speaking → const AgentState

The agent is producing audio output / speaking.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AgentState>
A constant List of the values in this enum, in order of their declaration.