CustomAudioTrackConfig enum

Defines audio quality presets for microphone audio tracks.

  • These presets control audio bitrate, channel configuration, and overall sound quality.

Encoder Config Reference

Encoder Config Bitrate Auto Gain Echo Cancellation Noise Suppression
speech_low_quality 16 kbps TRUE TRUE TRUE
speech_standard 24 kbps TRUE TRUE TRUE
music_standard 32 kbps FALSE FALSE FALSE
standard_stereo 64 kbps FALSE FALSE FALSE
high_quality 128 kbps FALSE TRUE FALSE
high_quality_stereo 192 kbps FALSE FALSE FALSE

Note: If you face issues related to echo, you can use noiseConfig with echoCancellation: true. Echo cancellation attempts to prevent echo effects on a two-way audio connection by reducing or eliminating crosstalk between the user's output device and their input device — for example, filtering out sound produced by the speakers from being captured by the microphone input track.

Example

final audioTrack = await VideoSDK.createMicrophoneAudioTrack(
  encoderConfig: CustomAudioTrackConfig.high_quality,
);
Inheritance
Available extensions

Values

speech_low_quality → const CustomAudioTrackConfig

Low-quality speech-optimized audio.

Example

encoderConfig: CustomAudioTrackConfig.speech_low_quality
speech_standard → const CustomAudioTrackConfig

Standard-quality speech audio (recommended).

Example

encoderConfig: CustomAudioTrackConfig.speech_standard
music_standard → const CustomAudioTrackConfig

Standard-quality music audio.

Example

encoderConfig: CustomAudioTrackConfig.music_standard
standard_stereo → const CustomAudioTrackConfig

Stereo audio with standard quality.

Example

encoderConfig: CustomAudioTrackConfig.standard_stereo
high_quality → const CustomAudioTrackConfig

High-quality mono audio.

Example

encoderConfig: CustomAudioTrackConfig.high_quality
high_quality_stereo → const CustomAudioTrackConfig

High-quality stereo audio.

Example

encoderConfig: CustomAudioTrackConfig.high_quality_stereo

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CustomAudioTrackConfig>
A constant List of the values in this enum, in order of their declaration.