FacingMode enum

Defines the camera facing mode for video capture.

  • This enum specifies which camera should be used when creating a camera video track.

Example

final videoTrack = await VideoSDK.createCameraVideoTrack(
  facingMode: FacingMode.user,
);
Inheritance
Available extensions

Values

environment → const FacingMode

Uses the rear-facing (environment) camera.

  • Typically used for capturing surroundings or external views.

Example

FacingMode.environment
user → const FacingMode

Uses the front-facing (user) camera.

-Commonly used for video calls and meetings.

Example

FacingMode.user

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FacingMode>
A constant List of the values in this enum, in order of their declaration.