id property
Unique id of the room where the participant has joined.
Type
String
Implementation
// Room Configuration Properties
late final String id;
Unique id of the room where the participant has joined.
String// Room Configuration Properties
late final String id;