participants property
A collection of all remote participants in the room.
This map contains all participants who have joined the room, excluding the localParticipant. Each entry is keyed by the participant’s unique ID.
Type
Map<String, Participant>
Example
// Access a remote participant by ID
const remoteParticipantId = 'ajf897';
final Participant? remoteParticipant =
room.participants[remoteParticipantId];
Implementation
final Map<String, Participant> participants = {};