RoomState enum

Defines the connection states of a room.

Example

room.on(Events.roomStateChanged, (RoomState state) {
  print('Room state changed to: $state');
});
Inheritance
Available extensions

Values

connecting → const RoomState

Indicates that the room is in the process of connecting.

Example

RoomState.connecting
connected → const RoomState

Indicates that the room is successfully connected.

Example

RoomState.connected
reconnecting → const RoomState

Indicates that the room connection was lost and is attempting to reconnect automatically.

Example

RoomState.reconnecting
disconnected → const RoomState

Indicates that the room has been disconnected.

Example

RoomState.disconnected

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RoomState>
A constant List of the values in this enum, in order of their declaration.