pause method
void
pause()
By using pause(), a participant can pause the stream of Remote Participant.
Example
stream.pause();
Implementation
void pause() => _pause();
By using pause(), a participant can pause the stream of Remote Participant.
stream.pause();
void pause() => _pause();