resume method

Future<void> resume()

By using resume(), a participant can resume the stream of Remote Participant.

Example

await stream.resume();

Returns a Future that completes when the resume request has been sent.

Implementation

Future<void> resume() => _resume();