VideoDeviceInfo class
Represents video device information.
- Inheritance
-
- Object
- MediaDeviceInfo
- DeviceInfo
- VideoDeviceInfo
Constructors
- VideoDeviceInfo({required String deviceId, String? groupId, String? kind, required String label})
- Creates a VideoDeviceInfo instance.
Properties
- deviceId → String
-
Returns a String that is an identifier for the represented device that
is persisted across sessions. It is un-guessable by other applications
and unique to the origin of the calling application. It is reset when
the user clears cookies (for Private Browsing, a different identifier
is used that is not persisted across sessions).
finalinherited
- groupId → String?
-
Returns a String that is a group identifier. Two devices have the same
group identifier if they belong to the same physical device
— for example a monitor with both a built-in camera and a microphone.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String?
-
Returns an enumerated value that is either 'videoinput', 'audioinput' or
'audiooutput'.
finalinherited
- label → String
-
Returns a String that is a label describing this device
(for example "External USB Webcam").
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited