CustomTrack class
Represents a custom media track.
- This class encapsulates a media stream and its configuration, such as encoder settings and optimization modes. It supports both audio and video tracks.
Properties
- audioEncoderConfig ↔ CustomAudioTrackConfig
-
Configuration for audio encoding.
getter/setter pair
- bitrateMode ↔ BitrateMode
-
The bitrate mode for the track.
getter/setter pair
- ended ↔ bool
-
Indicates if the track has ended.
getter/setter pair
- kind ↔ CustomTrackKind
-
The type of the track (audio, video, or share).
getter/setter pair
- maxLayer ↔ int
-
The maximum spatial layer for video.
getter/setter pair
- mediaStream ↔ MediaStream
-
The underlying WebRTC media stream.
getter/setter pair
- microphoneId ↔ String?
-
The ID of the microphone used for this track (audio only).
getter/setter pair
- multiStream ↔ bool
-
Whether the track supports multi-stream (simulcast).
getter/setter pair
-
noiseConfig
↔ Map<
String, bool> ? -
Configuration for noise cancellation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoEncoderConfig ↔ CustomVideoTrackConfig
-
Configuration for video encoding.
getter/setter pair