CustomVideoTrackConfig enum
Defines video resolution and encoding presets for camera video tracks.
- These presets control the width and height of the video stream and are used while creating a custom camera video track.
Example
final videoTrack = await VideoSDK.createCameraVideoTrack(
encoderConfig: CustomVideoTrackConfig.h720p_w1280p,
);
Values
- h90p_w160p → const CustomVideoTrackConfig
-
160x90 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h90p_w160p - h180p_w320p → const CustomVideoTrackConfig
-
320x180 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h180p_w320p - h216p_w384p → const CustomVideoTrackConfig
-
384x216 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h216p_w384p - h360p_w640p → const CustomVideoTrackConfig
-
640x360 video resolution (SD).
Example
encoderConfig: CustomVideoTrackConfig.h360p_w640p - h540p_w960p → const CustomVideoTrackConfig
-
960x540 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h540p_w960p - h720p_w1280p → const CustomVideoTrackConfig
-
1280x720 video resolution (HD).
Example
encoderConfig: CustomVideoTrackConfig.h720p_w1280p - h1080p_w1920p → const CustomVideoTrackConfig
-
1920x1080 video resolution (Full HD).
Example
encoderConfig: CustomVideoTrackConfig.h1080p_w1920p - h1440p_w2560p → const CustomVideoTrackConfig
-
2560x1440 video resolution (2K).
Example
encoderConfig: CustomVideoTrackConfig.h1440p_w2560p - h2160p_w3840p → const CustomVideoTrackConfig
-
3840x2160 video resolution (4K).
Example
encoderConfig: CustomVideoTrackConfig.h2160p_w3840p - h120p_w160p → const CustomVideoTrackConfig
-
160x120 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h120p_w160p - h144_w192p → const CustomVideoTrackConfig
-
192x144 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h144_w192p - h180p_w240p → const CustomVideoTrackConfig
-
240x180 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h180p_w240p - h240p_w320p → const CustomVideoTrackConfig
-
320x240 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h240p_w320p - h360p_w480p → const CustomVideoTrackConfig
-
480x360 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h360p_w480p - h480p_w640p → const CustomVideoTrackConfig
-
640x480 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h480p_w640p - h540p_w720p → const CustomVideoTrackConfig
-
720x540 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h540p_w720p - h720p_w960p → const CustomVideoTrackConfig
-
960x720 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h720p_w960p - h1080p_w1440p → const CustomVideoTrackConfig
-
1440x1080 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h1080p_w1440p - h1440p_w1920p → const CustomVideoTrackConfig
-
1920x1440 video resolution.
Example
encoderConfig: CustomVideoTrackConfig.h1440p_w1920p
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CustomVideoTrackConfig> - A constant List of the values in this enum, in order of their declaration.