Mode enum
Defines the media participation mode of a participant in the room.
-
This enum controls whether a participant can send and/or receive audio and video streams. The selected mode can be updated at runtime using the
changeMode()method. -
When a participant’s mode changes, the Events.participantModeChanged event is emitted with the participantId and the updated mode.
Example
room.changeMode(Mode.SEND_AND_RECV);
Values
- CONFERENCE → const Mode
-
Deprecated
Conference mode is deprecated and will be removed in future versions.
- Use Mode.SEND_AND_RECV instead.
Example
Mode.CONFERENCE - VIEWER → const Mode
-
Deprecated
Viewer mode is deprecated and will be removed in future versions.
- Use Mode.RECV_ONLY instead.
Example
Mode.VIEWER - SEND_AND_RECV → const Mode
-
Enables both sending and receiving of audio and video streams.
- This is the default and recommended mode for most participants.
Example
Mode.SEND_AND_RECV - SIGNALLING_ONLY → const Mode
-
Disables sending and receiving of audio and video streams.
- This mode is used only for signaling purposes.
Example
Mode.SIGNALLING_ONLY - RECV_ONLY → const Mode
-
Enables receiving audio and video streams without producing any.
- Useful for participants who only need to watch or listen.
Example
Mode.RECV_ONLY
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited