PostTranscriptionConfig class
Configuration for post-transcription processing.
- This class defines the settings for actions that should be performed after transcription is completed, such as generating summaries or selecting a specific AI model.
Properties
- enabled ↔ bool
-
Whether post-transcription processing is enabled.
latefinal
- modelId ↔ String?
-
Identifier of the AI model to be used for post-transcription processing.
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary ↔ SummaryConfig?
-
Configuration for generating a transcription summary.
latefinal