By using resume(), a participant can resume the stream of Remote Participant.
await stream.resume();
Returns a Future that completes when the resume request has been sent.
Future<void> resume() => _resume();